@@ -1,5 +1,5 @@
-# Gufw 19.04.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw - https://costales.github.io/projects/gufw/
+# Copyright (C) 2008-2023 Marcos Alvarez Costales https://costales.github.io
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ class Firewall():
         if not self.status:
             self.backend.set_status(True)
         # Remove Gufw rules previous profile
-        old_rules = self.get_rules()
+        old_rules = self.get_rules(False)
         ind = len(old_rules)
         for old_row in reversed(old_rules):
             if old_row['command']: # It's a gufw rule
@@ -132,7 +132,7 @@ class Firewall():
     def set_status(self, status):
         self.status = status
         self.backend.set_status(status)
-        self.backend.set_profile_values(self.profile, status, self.incoming, self.outgoing, self.routed, self.get_rules())
+        self.backend.set_profile_values(self.profile, status, self.incoming, self.outgoing, self.routed, self.get_rules(not status))
     
     def get_policy(self, policy):
         if policy == 'incoming':
@@ -156,20 +156,22 @@ class Firewall():
             self.routed = value
             self.backend.set_policy(policy, value)
         
-        self.backend.set_profile_values(self.profile, self.status, self.incoming, self.outgoing, self.routed, self.get_rules())
+        self.backend.set_profile_values(self.profile, self.status, self.incoming, self.outgoing, self.routed, self.get_rules(True))
     
     def reset(self):
         self.backend.set_profile_values(self.profile, self.status, self.incoming, self.outgoing, self.routed, [])
         self.backend.reset_fw()
     
     # RULES
-    def get_rules(self):
+    def get_rules(self, force_fw_on):
         if self.backend.get_status():
             ufw_rules = self.backend.get_rules()
         else:
-            self.backend.set_status(True)
+            if force_fw_on:
+                self.backend.set_status(True)
             ufw_rules = self.backend.get_rules()
-            self.backend.set_status(False)
+            if force_fw_on:
+                self.backend.set_status(False)
         profile_rules = self._get_rules_profile()
         return self._compose_rules(ufw_rules, profile_rules)
     
@@ -177,11 +179,11 @@ class Firewall():
         return self.backend.get_number_rules()
     
     def add_rule(self, description, insert, policy, direction, iface, routed, logging, proto, from_ip, from_port, to_ip, to_port):
-        rules_before = self.get_rules()
+        rules_before = self.get_rules(True)
         rules_profile_before = self._get_rules_profile()
         
         cmd = self.backend.add_rule(insert, policy, direction, iface, routed, logging, proto, from_ip, from_port, to_ip, to_port)
-        rules_after = self.get_rules()
+        rules_after = self.get_rules(True)
         
         if len(rules_before) != len(rules_after):
             cmd.insert(0, True)
@@ -191,10 +193,10 @@ class Firewall():
         return cmd # For logging
     
     def delete_rule(self, num):
-        rules_before = self.get_rules()
+        rules_before = self.get_rules(True)
         rules_profile_before = self._get_rules_profile()
         result = self.backend.delete_rule(str(num))
-        rules_after = self.get_rules()
+        rules_after = self.get_rules(True)
         self._regenerate_file_profile(rules_before, rules_profile_before, rules_after)
         return result # For logging
     
